@@ -4,8 +4,6 @@
 #### How the coefficients shrink
 ################################
 
-#### usage: ridge.plot(target, dataset, lambda = seq(0, 5, by = 0.1) ) 
-
 ridge.plot <- function(target, dataset, lambda = seq(0, 5, by = 0.1) ) {
   ## target is the dependent variable and can only be a vector
   ## dataset contains the independent, CONTINUOUS ONLY, variables
@@ -19,9 +17,9 @@ ridge.plot <- function(target, dataset, lambda = seq(0, 5, by = 0.1) ) {
   yy <- target - mean(target)  ## center the dependent variables
   xx <- scale(dataset)[1:n, ]  ## standardize the independent variables
   sa <- svd(xx)
-  u <- sa$u ;  d <- sa$d  ;  v <- sa$v
+  u <- t(sa$u) ;  d <- sa$d  ;  v <- sa$v
   for (i in 1:R) {
-    be[, i] <- ( v %*% diag( d/( d^2 + lambda[i] ) ) %*% t(u) ) %*% yy 
+    be[, i] <- ( v %*% diag( d/( d^2 + lambda[i] ) ) %*% u ) %*% yy 
   }
   plot(lambda, be[1,], type = "l", col = 1, lty = 1,
   ylim = c( min(be), max(be) ), xlab = expression(paste(lambda, " values")), 
